==> Banners-2.3.7.tar.gz: Banners/lang/ext/fr_FR.php <==
<?php
$lang['help_param_action'] = 'Pr&eacute;cisent le comportement du module. Les valeurs possibles sont &amp;quot;default&amp;quot; et &amp;quot;list&amp;quot;. L&#039;action par d&eacute;faut est utilis&eacute; pour afficher une banni&egrave;re unique selon le crit&egrave;re sp&eacute;cifi&eacute;. L&#039;action de liste est utilis&eacute; pour afficher toutes les banni&egrave;res d&#039;une cat&eacute;gorie ou d&#039;un Id de cat&eacute;gorie';
$lang['help_param_category'] = 'Dans l&#039;action par d&eacute;faut, ce param&egrave;tre est utilis&eacute; pour sp&eacute;cifier le nom de la cat&eacute;gorie dans laquelle une seule banni&egrave;re sera affich&eacute;e. Dans l&#039;action Liste ce param&egrave;tre est n&eacute;cessaire pour pr&eacute;ciser le nom de la cat&eacute;gorie dans laquelle toutes les banni&egrave;res seront affich&eacute;es';
$lang['help_param_mode'] = 'Ce param&egrave;tre est uniquement  utilis&eacute; pour l&#039;action par d&eacute;faut, il pr&eacute;cise la fa&ccedil;on dont les banni&egrave;res sont choisis dans la cat&eacute;gorie sp&eacute;cifi&eacute;e. La seule valeur est &amp;quot;sequential&amp;quot;, qui indique que le module devrait choisir le prochain non expir&eacute; banni&egrave;re avec le moins d&#039;impressions. Ne pas pr&eacute;ciser ce param&egrave;tre se traduira par une banni&egrave;re s&eacute;lectionn&eacute;e al&eacute;atoirement';
$lang['help_param_name'] = 'Ce param&egrave;tre est uniquement utilis&eacute; pour l&#039;action par d&eacute;faut. Il d&eacute;finit un nom absolu pour une banni&egrave;re &agrave; charger. Dans le cas ou la banni&egrave;re est invalide (nombre d&#039;impression d&eacute;pass&eacute; ou si expir&eacute;), rien ne sera retourn&eacute;.';
$lang['bannerlist_template'] = 'Gabarit de la liste des Banni&egrave;res';
$lang['info_bannerlist_template'] = 'Utilis&eacute; avec l&#039;action Liste, ce mod&egrave;le contr&ocirc;le l&#039;affichage de toutes les banni&egrave;res de la cat&eacute;gorie s&eacute;lectionn&eacute;e';
$lang['none'] = 'Aucun';
$lang['error_invalid_dates'] = 'Erreur Dates Invalides';
$lang['editbanner'] = 'Editer la banni&egrave;re';
$lang['start_date'] = 'Date de d&eacute;but';
$lang['atttext'] = '&agrave;';
$lang['template'] = 'Gabarit';
$lang['default_template'] = 'Gabarit des cat&eacute;gories par d&eacute;faut';
$lang['reset_template'] = 'Remettre au gabarit par d&eacute;faut';
$lang['error_banners'] = 'Aucune banni&egrave;re';
$lang['error_bannerexists'] = 'Une banni&egrave;re avec ce nom existe d&eacute;j&agrave;';
$lang['accessdenied'] = 'Acc&egrave;s refus&eacute;. Veuillez v&eacute;rifier vos permissions';
$lang['addbanner'] = 'Ajout de banni&egrave;re';
$lang['addcategory'] = 'Ajout de cat&eacute;gorie';
$lang['areyousure'] = '&Ecirc;tes-vous s&ucirc;r ?';
$lang['banners'] = 'Banni&egrave;res';
$lang['cancel'] = 'Annuler';
$lang['categories'] = 'Cat&eacute;gories';
$lang['category'] = 'Cat&eacute;gorie';
$lang['created'] = 'Cr&eacute;&eacute;e';
$lang['date'] = 'Date ';
$lang['delete'] = 'Supprimer';
$lang['description'] = 'Description ';
$lang['edit'] = '&Eacute;diter';
$lang['editcategory'] = '&Eacute;diter la cat&eacute;gorie';
$lang['error'] = 'Erreur!';
$lang['error_banerexists'] = 'Une banni&egrave;re avec ce nom existe d&eacute;j&agrave;';
$lang['error_categorynotempty'] = 'Erreur&nbsp;: cat&eacute;gorie non vide !';
$lang['error_dberror'] = 'Erreur&nbsp;: erreur de base de donn&eacute;es !';
$lang['error_emptybannername'] = 'Erreur&nbsp;: nom de banni&egrave;re vide !';
$lang['error_emptycategory'] = 'Erreur&nbsp;: cat&eacute;gorie vide !';
$lang['error_insufficientparams'] = 'Erreur&nbsp;: entr&eacute;e insuffisante';
$lang['error_nocategories'] = 'Erreur&nbsp;: aucune cat&eacute;gorie trouv&eacute;e';
$lang['error_noresults'] = 'Aucune banni&egrave;re ne correspond &agrave; la requ&ecirc;te';
$lang['error_textorimage'] = 'Sp&eacute;cifiez l&#039;URL et l&#039;IMAGE ou le TEXTE, pas les deux';
$lang['expires'] = 'Expire';
$lang['friendlyname'] = 'Banni&egrave;res';
$lang['height'] = 'Hauteur';
$lang['hits'] = 'Clics';
$lang['href_text'] = 'Texte du lien';
$lang['id'] = 'ID ';
$lang['image'] = 'Image ';
$lang['image_text'] = 'Texte de l&#039;image';
$lang['impressions'] = 'Impressions ';
$lang['info_href_text'] = 'Texte suppl&eacute;mentaire pour la balise lien. Ce texte est plac&eacute; dans la balise.';
$lang['info_image'] = 'Sp&eacute;cifiez un fichier relatif &agrave; votre dossier &#039;uploads&#039;';
$lang['info_image_text'] = 'Texte suppl&eacute;mentaire pour la balise image';
$lang['info_max_hits'] = 'Entrez 0 pour un nombre de clics illimit&eacute;s';
$lang['info_max_impressions'] = 'Entrez 0 pour un nombre d&#039;impressions illimit&eacute;es';
$lang['installed'] = 'La version %s du module est install&eacute;e.';
$lang['ipaddress'] = 'Adresse IP';
$lang['max_hits'] = 'Nombre maximal de clics';
$lang['max_impressions'] = 'Nombre maximal d&#039;impressions';
$lang['name'] = 'Nom';
$lang['never'] = 'Jamais';
$lang['postinstall'] = 'Message apr&egrave;s installation, Assurez-vous d&#039;avoir donn&eacute; la permission &quot;Manage Banners&quot; (ou Gestion des banni&egrave;res) aux groupes qui utiliseront ce module !';
$lang['postuninstall'] = 'Le module Banners a &eacute;t&eacute; d&eacute;sinstall&eacute;, et les tables de la base supprim&eacute;es.';
$lang['preferences'] = 'Pr&eacute;f&eacute;rences';
$lang['prefsupdated'] = 'Les pr&eacute;f&eacute;rences du modules ont &eacute;t&eacute; mises &agrave; jour';
$lang['prompt_categorydesc'] = 'Description de la cat&eacute;gorie';
$lang['prompt_categoryname'] = 'Nom de la cat&eacute;gorie';
$lang['prompt_imageheight'] = 'Hauteur de l&#039;image';
$lang['prompt_imagewidth'] = 'Largeur de l&#039;image';
$lang['prompt_subnet_exclusions'] = 'Excluez ces subnets de toute collecte de statistique';
$lang['prompt_upload_category'] = 'Cat&eacute;gorie (Module Uploads)';
$lang['prompt_upload_file'] = 'Image (Module Uploads)';
$lang['selectcategory'] = 'S&eacute;lection de cat&eacute;gorie';
$lang['submit'] = 'Envoyer';
$lang['text'] = 'Texte';
$lang['title_mod_admin'] = 'Panneau d&#039;administration du module';
$lang['title_mod_prefs'] = 'Pr&eacute;f&eacute;rences du module';
$lang['uninstalled'] = 'Module d&eacute;sinstall&eacute;';
$lang['upgraded'] = 'Module mis &agrave; jour &agrave; la version %s.';
$lang['url'] = 'URL ';
$lang['width'] = 'Largeur';
$lang['title_admin_panel'] = 'Banni&egrave;res';
$lang['moddescription'] = 'Un module pour la gestion des banni&egrave;res rotatives';
$lang['welcome_text'] = '<p>Bienvenue dans le panneau d&#039;administration du module de gestion des banni&egrave;res.</p>';
$lang['changelog'] = '<ul>
<li>Version 1.0. 6 Ao&ucirc;t 2005. Version initiale.</li>
<li>Version 2.0. Septembre 2005. Version initiale pour 0.1.</li>
<li>Version 2.0.1. Septembre 2005. Affichage des banni&egrave;res d&#039;exemple dans la page d&#039;&eacute;dition des banni&egrave;res, ajout de name= param&egrave;tre, et fait fonctionn&eacute; l&#039;exclusion de subnets.  Egalement changement de la d&eacute;finition de la base de donn&eacute;es pour permettre l&#039;ajout de texte suppl&eacute;mentaire dans les liens text et image.</li>
<li>Version 2.0.2. Septembre 2005. Ajout de l&#039;int&eacute;gration au module Uploads (version 1.0.6) afin de pouvoir obtenir les fichiers pour les banni&egrave;res. Le module Banni&egrave;res est cependant toujours optionnel.</li>
<li>Version 2.0.3. Septembre 2005. Correction d&#039;un bug mineur lorsque l&#039;expiration est fix&eacute;e &agrave; &quot;jamais&quot;</li>
<li>Version 2.0.4. Septembre 2005. Correction d&#039;un bug mineur avec les associations de modules, et d&#039;un plus gros bug dans les sp&eacute;cifications de la base de donn&eacute;e lors d&#039;une installation fra&icirc;che.</li>
<li>Version 2.0.5. Octobre 2005. Ajout de commentaires autour du code g&eacute;n&eacute;r&eacute;</li>
<li>Version 2.0.6. D&eacute;cembre 2005. Correction en rapport avec la validation, la description est maintenant g&eacute;n&eacute;r&eacute;e entre les balises <img> et </img>, et un attribut alt est maintenant dans la balise img.</li>
<li>Version 2.0.7. Janvier 2006. Corrections en rapport avec la validation, d&eacute;placement des onglets du panneau d&#039;administration, correction d&#039;un probl&egrave;me o&ugrave; la cr&eacute;ation d&#039;une banni&egrave;re sans cat&eacute;gorie &eacute;tait presque possible, et .... correction du probl&egrave;me de la date d&#039;expiration pour de bon (esp&eacute;rons).</li>
<li>Version 2.1.0. Ao&ucirc;t 2006. Pr&eacute;paration pour la compatibilit&eacute; avec 1.0, fichiers multiples, r&eacute;f&eacute;rences utilis&eacute;es l&agrave; o&ugrave; c&#039;est possible, messages am&eacute;lior&eacute;s, et nettoyage g&eacute;n&eacute;ral.</li>
<li>Version 2.2. Mars 2008. 
    <p>La premi&egrave;re sortie depuis un moment, qui corrige des probl&egrave;mes avec les champs de date, et la date d&#039;expiration. Int&egrave;gre &eacute;galement des changements de sorte que l&#039;onglet actif soit Maintaned (DeeEye) et licence modifi&eacute;e.</p>
    <p>Requiert CMS 1.2.3 ou plus</p>
</li>
<li>Version 2.2.1. Avril 2008.
    <p>Corrections mineures.</p>
</li>
</ul>
<li>Version 2.2.3. Avril 2009.
    <p>Suppression des param&egrave;tres de largeur et hauteur, ajout d&#039;une date de d&eacute;part et utilisation de templates. remaniement majeur.</p>
</li>
<li>Version 2.3 - Septembre 2009.
  <ul>
    <li>Correction majeure du code</li>
    <li>Suppression du param&egrave;tre de non-expiration... il faut utiliser des dates lointaines &agrave; la place.</li>
    <li>Ne emande plus d&#039;ins&eacute;rer des heures, seulement des jours</li>
    <li>Correction afin d&#039;utiliser la plus r&eacute;cente version du module Uploads, quand il est pr&eacute;sent.</li>
    <li>Ajout de d&eacute;pendance au module CGExtensions</li>
    <li>Ajout de l&#039;action Banner list.</li>
  </ul>
</li>
<li>Version 2.3.1 - Septembre 2009.
  <ul>
    <li>Corrections.</li>
  </ul>
</li>
<li>Version 2.3.2 - Octobre 2009.
  <ul>
    <li>Corrections mineures.</li>
  </ul>
</li>
</ul>';
$lang['help'] = '<h3>Que fait ce module ?</h3>
<p>Ce module g&egrave;re des cat&eacute;gories multiples de banni&egrave;res, suit le nombre de clics (Hits), le nombre d&#039;impressions, ainsi que les dates d&#039;expiration, et s&eacute;lectionne au hasard la banni&egrave;re &agrave; afficher parmi les fichiers valides.</p>
<h3>Comment l&#039;utiliser ?</h3>
<p>Pour utiliser ce module, placez le code dans une page ou un gabarit, en utilisant la balise Smarty {cms_module module=&#039;Banners&#039; category=&#039;<cat&eacute;gorie>&#039;}</p> 
<p>Vous devez &eacute;galement ajouter des banni&egrave;res dans un dossier d&eacute;di&eacute; sous le dossier uploads et devez utiliser l&#039;interface du panneau d&#039;administration pour ajouter les banni&egrave;res &agrave; la base de donn&eacute;es.</p
<h3>Param&egrave;tres</h3>
<ul>
<li><em>(REQUIS)</em> category=&quot;category&quot; = s&eacute;lectionne au hasard une banni&egrave;re de cette cat&eacute;gorie</li>
<li><em>(optionel)</em> name=&quot;name&quot; = s&eacute;lectionne uniquement la banni&egrave;re de ce nom</li>
</ul>
<h3>Astuce</h3>
<p>Le module Uploads et le module Banni&egrave;res fonctionnent bien ensemble. Vous pouvez cr&eacute;er une cat&eacute;gorie &quot;banners&quot; dans le module Uploads, et t&eacute;l&eacute;charger vos images banni&egrave;res &agrave; cet endroit, puis sp&eacute;cifier&quot;banners/<nomfichier>&quot; lorsque vous ajoutez une banni&egrave;re dans le module Banni&egrave;res.</p>
<h3>Support</h3>
<p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
<ul>
<li>For the latest version of this module, FAQs, or to file a Bug Report or buy commercial support, please visit calguy&#039;s
module homepage at <a href="http://techcom.dyndns.org">techcom.dyndns.org</a>.</li>
<li>Additional discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forums</a>.</li>
<li>The author, calguy1000, can often be found in the <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a>.</li>
<li>Lastly, you may have some success emailing the author directly.</li>  
</ul>
<h3>Copyright and License</h3>
<p>Copyright &amp;copy; 2008, Robert Campbel <a href="mailto:calguy1000@cmsmadesimple.org">&amp;lt;calguy1000@cmsmadesimple.org&amp;gt;</a>. All Rights Are Reserved.</p>
<p>This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.</p>
<p>However, as a special exception to the GPL, this software is distributed
as an addon module to CMS Made Simple.  You may not use this software
in any Non GPL version of CMS Made simple, or in any version of CMS
Made simple that does not indicate clearly and obviously in its admin 
section that the site was built with CMS Made simple.</p>
<p>This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
Or read it <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p>';
$lang['utma'] = '156861353.3191881680569258500.1232756883.1254791275.1254870961.36';
$lang['utmz'] = '156861353.1254791275.35.19.utmccn=(referral)|utmcsr=virtuaza.com|utmcct=/clients/argt/admin/systeminfo.php|utmcmd=referral';
$lang['qca'] = 'P0-1396490256-1250376412325';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>

==> Banners-2.6.tar.gz: Banners/lang/ext/fr_FR.php <==
<?php
$lang['statreport_linesperpage'] = 'Lignes par page dans le rapport de statistiques.';
$lang['banner'] = 'Banni&egrave;re publicitaire';
$lang['of'] = 'De';
$lang['page'] = 'Page ';
$lang['generated'] = 'G&eacute;n&eacute;r&eacute;';
$lang['generated_by'] = 'G&eacute;n&eacute;r&eacute; par';
$lang['desc_stats_report'] = 'Un rapport illustre le nombre d&#039;affichage et de clic sur le module Banners';
$lang['title_stats_report'] = 'Rapport des statistiques des banni&egrave;res';
$lang['view_statistics'] = 'Voir les Statistiques';
$lang['msg_new_window'] = 'Cr&eacute;&eacute; une nouvelle fen&ecirc;tre';
$lang['statreport_template'] = 'Gabarit du rapport de statistiques';
$lang['your_ad_here'] = 'Votre publicit&eacute; pourrait &ecirc;tre ici';
$lang['prompt_dflt_image'] = 'Image par d&eacute;faut';
$lang['prompt_dflt_url'] = 'URL par d&eacute;faut';
$lang['info_dflt_image'] = 'Sp&eacute;cifier un nom d&#039;image (relatif au r&eacute;pertoire d&#039;upload) d&#039;une image &agrave; utiliser lorsque aucune banni&egrave;re valide ne peut &ecirc;tre affich&eacute;e.';
$lang['prompt_hidefrombots'] = 'Exlure les robots du compte d&#039;affichage';
$lang['help_param_action'] = 'Pr&eacute;cisent le comportement du module. Les valeurs possibles sont &amp;quot;default&amp;quot; et &amp;quot;list&amp;quot;. L&#039;action par d&eacute;faut est utilis&eacute; pour afficher une banni&egrave;re unique selon le crit&egrave;re sp&eacute;cifi&eacute;. L&#039;action de liste est utilis&eacute; pour afficher toutes les banni&egrave;res d&#039;une cat&eacute;gorie ou d&#039;un Id de cat&eacute;gorie';
$lang['help_param_category'] = 'Dans l&#039;action par d&eacute;faut, ce param&egrave;tre est utilis&eacute; pour sp&eacute;cifier le nom de la cat&eacute;gorie dans laquelle une seule banni&egrave;re sera affich&eacute;e. Dans l&#039;action Liste ce param&egrave;tre est n&eacute;cessaire pour pr&eacute;ciser le nom de la cat&eacute;gorie dans laquelle toutes les banni&egrave;res seront affich&eacute;es';
$lang['help_param_mode'] = 'Ce param&egrave;tre est uniquement  utilis&eacute; pour l&#039;action par d&eacute;faut, il pr&eacute;cise la fa&ccedil;on dont les banni&egrave;res sont choisis dans la cat&eacute;gorie sp&eacute;cifi&eacute;e. La seule valeur est &amp;quot;sequential&amp;quot;, qui indique que le module devrait choisir le prochain non expir&eacute; banni&egrave;re avec le moins d&#039;impressions. Ne pas pr&eacute;ciser ce param&egrave;tre se traduira par une banni&egrave;re s&eacute;lectionn&eacute;e al&eacute;atoirement';
$lang['help_param_name'] = 'Ce param&egrave;tre est uniquement utilis&eacute; pour l&#039;action par d&eacute;faut. Il d&eacute;finit un nom absolu pour une banni&egrave;re &agrave; charger. Dans le cas ou la banni&egrave;re est invalide (nombre d&#039;impression d&eacute;pass&eacute; ou si expir&eacute;), rien ne sera retourn&eacute;.';
$lang['bannerlist_template'] = 'Gabarit de la liste des Banni&egrave;res';
$lang['info_bannerlist_template'] = 'Utilis&eacute; avec l&#039;action Liste, ce mod&egrave;le contr&ocirc;le l&#039;affichage de toutes les banni&egrave;res de la cat&eacute;gorie s&eacute;lectionn&eacute;e';
$lang['none'] = 'Aucun';
$lang['error_invalid_dates'] = 'Erreur Dates Invalides';
$lang['editbanner'] = 'Editer la banni&egrave;re';
$lang['start_date'] = 'Date de d&eacute;but';
$lang['atttext'] = '&agrave;';
$lang['template'] = 'Gabarit';
$lang['default_template'] = 'Gabarit des cat&eacute;gories par d&eacute;faut';
$lang['reset_template'] = 'Remettre au gabarit par d&eacute;faut';
$lang['error_banners'] = 'Aucune banni&egrave;re';
$lang['error_bannerexists'] = 'Une banni&egrave;re avec ce nom existe d&eacute;j&agrave;';
$lang['accessdenied'] = 'Acc&egrave;s refus&eacute;. Veuillez v&eacute;rifier vos permissions';
$lang['addbanner'] = 'Ajout de banni&egrave;re';
$lang['addcategory'] = 'Ajout de cat&eacute;gorie';
$lang['areyousure'] = '&Ecirc;tes-vous s&ucirc;r ?';
$lang['banners'] = 'Banni&egrave;res';
$lang['cancel'] = 'Annuler';
$lang['categories'] = 'Cat&eacute;gories';
$lang['category'] = 'Cat&eacute;gorie';
$lang['created'] = 'Cr&eacute;&eacute;e';
$lang['date'] = 'Date ';
$lang['delete'] = 'Supprimer';
$lang['description'] = 'Description ';
$lang['edit'] = '&Eacute;diter';
$lang['editcategory'] = '&Eacute;diter la cat&eacute;gorie';
$lang['error'] = 'Erreur!';
$lang['error_banerexists'] = 'Une banni&egrave;re avec ce nom existe d&eacute;j&agrave;';
$lang['error_categorynotempty'] = 'Erreur&nbsp;: cat&eacute;gorie non vide !';
$lang['error_dberror'] = 'Erreur&nbsp;: erreur de base de donn&eacute;es !';
$lang['error_emptybannername'] = 'Erreur&nbsp;: nom de banni&egrave;re vide !';
$lang['error_emptycategory'] = 'Erreur&nbsp;: cat&eacute;gorie vide !';
$lang['error_insufficientparams'] = 'Erreur&nbsp;: entr&eacute;e insuffisante';
$lang['error_nocategories'] = 'Erreur&nbsp;: aucune cat&eacute;gorie trouv&eacute;e';
$lang['error_noresults'] = 'Aucune banni&egrave;re ne correspond &agrave; la requ&ecirc;te';
$lang['error_textorimage'] = 'Sp&eacute;cifiez l&#039;URL et l&#039;IMAGE ou le TEXTE, pas les deux';
$lang['expires'] = 'Expire';
$lang['friendlyname'] = 'Banni&egrave;res';
$lang['height'] = 'Hauteur';
$lang['hits'] = 'Clics';
$lang['href_text'] = 'Texte du lien';
$lang['id'] = 'ID ';
$lang['image'] = 'Image ';
$lang['image_text'] = 'Texte de l&#039;image';
$lang['impressions'] = 'Impressions ';
$lang['info_href_text'] = 'Texte suppl&eacute;mentaire pour la balise lien. Ce texte est plac&eacute; dans la balise.';
$lang['info_image'] = 'Sp&eacute;cifiez un fichier relatif &agrave; votre dossier &#039;uploads&#039;';
$lang['info_image_text'] = 'Texte suppl&eacute;mentaire pour la balise image';
$lang['info_max_hits'] = 'Entrez 0 pour un nombre de clics illimit&eacute;s';
$lang['info_max_impressions'] = 'Entrez 0 pour un nombre d&#039;impressions illimit&eacute;es';
$lang['installed'] = 'La version %s du module est install&eacute;e.';
$lang['ipaddress'] = 'Adresse IP';
$lang['max_hits'] = 'Nombre maximal de clics';
$lang['max_impressions'] = 'Nombre maximal d&#039;impressions';
$lang['name'] = 'Nom';
$lang['never'] = 'Jamais';
$lang['postinstall'] = 'Message apr&egrave;s installation, Assurez-vous d&#039;avoir donn&eacute; la permission &quot;Manage Banners&quot; (ou Gestion des banni&egrave;res) aux groupes qui utiliseront ce module !';
$lang['postuninstall'] = 'Le module Banners a &eacute;t&eacute; d&eacute;sinstall&eacute;, et les tables de la base supprim&eacute;es.';
$lang['preferences'] = 'Pr&eacute;f&eacute;rences';
$lang['prefsupdated'] = 'Les pr&eacute;f&eacute;rences du modules ont &eacute;t&eacute; mises &agrave; jour';
$lang['prompt_categorydesc'] = 'Description de la cat&eacute;gorie';
$lang['prompt_categoryname'] = 'Nom de la cat&eacute;gorie';
$lang['prompt_imageheight'] = 'Hauteur de l&#039;image';
$lang['prompt_imagewidth'] = 'Largeur de l&#039;image';
$lang['prompt_subnet_exclusions'] = 'Excluez ces subnets de toute collecte de statistique';
$lang['prompt_upload_category'] = 'Cat&eacute;gorie (Module Uploads)';
$lang['prompt_upload_file'] = 'Image (Module Uploads)';
$lang['selectcategory'] = 'S&eacute;lection de cat&eacute;gorie';
$lang['submit'] = 'Envoyer';
$lang['text'] = 'Texte';
$lang['title_mod_admin'] = 'Panneau d&#039;administration du module';
$lang['title_mod_prefs'] = 'Pr&eacute;f&eacute;rences du module';
$lang['uninstalled'] = 'Module d&eacute;sinstall&eacute;';
$lang['upgraded'] = 'Module mis &agrave; jour &agrave; la version %s.';
$lang['url'] = 'URL ';
$lang['width'] = 'Largeur';
$lang['title_admin_panel'] = 'Banni&egrave;res';
$lang['moddescription'] = 'Un module pour la gestion des banni&egrave;res rotatives';
$lang['welcome_text'] = '<p>Bienvenue dans le panneau d&#039;administration du module de gestion des banni&egrave;res.</p>';
$lang['help'] = '<h3>Que fait ce module ?</h3>
<p>Ce module g&egrave;re des cat&eacute;gories multiples de banni&egrave;res, suit le nombre de clics (Hits), le nombre d&#039;impressions, ainsi que les dates d&#039;expiration, et s&eacute;lectionne au hasard la banni&egrave;re &agrave; afficher parmi les fichiers valides.</p>
<h3>Comment l&#039;utiliser ?</h3>
<p>Pour utiliser ce module, placez le code dans une page ou un gabarit, en utilisant la balise Smarty {cms_module module=&#039;Banners&#039; category=&#039;<cat&eacute;gorie>&#039;}</p> 
<p>Vous devez &eacute;galement ajouter des banni&egrave;res dans un dossier d&eacute;di&eacute; sous le dossier uploads et devez utiliser l&#039;interface du panneau d&#039;administration pour ajouter les banni&egrave;res &agrave; la base de donn&eacute;es.</p
<h3>Param&egrave;tres</h3>
<ul>
<li><em>(REQUIS)</em> category=&quot;category&quot; = s&eacute;lectionne au hasard une banni&egrave;re de cette cat&eacute;gorie</li>
<li><em>(optionel)</em> name=&quot;name&quot; = s&eacute;lectionne uniquement la banni&egrave;re de ce nom</li>
</ul>
<h3>Astuce</h3>
<p>Le module Uploads et le module Banni&egrave;res fonctionnent bien ensemble. Vous pouvez cr&eacute;er une cat&eacute;gorie &quot;banners&quot; dans le module Uploads, et t&eacute;l&eacute;charger vos images banni&egrave;res &agrave; cet endroit, puis sp&eacute;cifier&quot;banners/<nomfichier>&quot; lorsque vous ajoutez une banni&egrave;re dans le module Banni&egrave;res.</p>
<h3>Support</h3>
<p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
<ul>
<li>For the latest version of this module, FAQs, or to file a Bug Report or buy commercial support, please visit calguy&#039;s
module homepage at <a href="http://techcom.dyndns.org">techcom.dyndns.org</a>.</li>
<li>Additional discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forums</a>.</li>
<li>The author, calguy1000, can often be found in the <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a>.</li>
<li>Lastly, you may have some success emailing the author directly.</li>  
</ul>
<h3>Copyright and License</h3>
<p>Copyright &amp;copy; 2008, Robert Campbel <a href="mailto:calguy1000@cmsmadesimple.org">&amp;lt;calguy1000@cmsmadesimple.org&amp;gt;</a>. All Rights Are Reserved.</p>
<p>This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.</p>
<p>However, as a special exception to the GPL, this software is distributed
as an addon module to CMS Made Simple.  You may not use this software
in any Non GPL version of CMS Made simple, or in any version of CMS
Made simple that does not indicate clearly and obviously in its admin 
section that the site was built with CMS Made simple.</p>
<p>This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
Or read it <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p>';
?>
